@@ -1,6 +1,6 @@
 package Games::Cards::Pair;
 
-$Games::Cards::Pair::VERSION   = '0.18';
+$Games::Cards::Pair::VERSION   = '0.19';
 $Games::Cards::Pair::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Games::Cards::Pair - Interface to the Pelmanism (Pair) Card Game.
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
@@ -25,7 +25,7 @@ use Games::Cards::Pair::Params qw(ZeroOrOne Cards);
 use Games::Cards::Pair::Card;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 
 use overload ('""' => \&as_string);
 
